@@ -91,23 +91,23 @@ public:
     {
     }
     using ObjectImpVisitor::visit;
-    void visit( const LineImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const PointImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const TextImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const AngleImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const VectorImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const LocusImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const CircleImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const ConicImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const CubicImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const SegmentImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const RayImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const ArcImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const FilledPolygonImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const ClosedPolygonalImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const OpenPolygonalImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const BezierImp* imp ) Q_DECL_OVERRIDE;
-    void visit( const RationalBezierImp* imp ) Q_DECL_OVERRIDE;
+    void visit( const LineImp* imp ) override;
+    void visit( const PointImp* imp ) override;
+    void visit( const TextImp* imp ) override;
+    void visit( const AngleImp* imp ) override;
+    void visit( const VectorImp* imp ) override;
+    void visit( const LocusImp* imp ) override;
+    void visit( const CircleImp* imp ) override;
+    void visit( const ConicImp* imp ) override;
+    void visit( const CubicImp* imp ) override;
+    void visit( const SegmentImp* imp ) override;
+    void visit( const RayImp* imp ) override;
+    void visit( const ArcImp* imp ) override;
+    void visit( const FilledPolygonImp* imp ) override;
+    void visit( const ClosedPolygonalImp* imp ) override;
+    void visit( const OpenPolygonalImp* imp ) override;
+    void visit( const BezierImp* imp ) override;
+    void visit( const RationalBezierImp* imp ) override;
 
     double unit;
 
@@ -525,7 +525,7 @@ void LatexExporter::run( const KigPart& doc, KigWidget& w )
         QStandardPaths::writableLocation( QStandardPaths::DocumentsLocation ), i18n( "Latex Documents (*.tex)" ),
         i18n( "Export as Latex" ), &w );
     kfd->setOptionCaption( i18n( "Latex Options" ) );
-    LatexExporterOptions* opts = new LatexExporterOptions( 0L );
+    LatexExporterOptions* opts = new LatexExporterOptions( nullptr );
     kfd->setOptionsWidget( opts );
 
     opts->setGrid( doc.document().grid() );
