@@ -1,20 +1,7 @@
-// Copyright (C)  2004 Pino Toscano <toscano.pino@tiscali.it>
-// Copyright (C)  2012 Raoul Bourquin <raoulb@bluewin.ch>
+// SPDX-FileCopyrightText: 2004 Pino Toscano <toscano.pino@tiscali.it>
+// SPDX-FileCopyrightText: 2012 Raoul Bourquin <raoulb@bluewin.ch>
 
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-// 02110-1301, USA.
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef KIG_FILTERS_PGFEXPORTERIMPVISITOR_H
 #define KIG_FILTERS_PGFEXPORTERIMPVISITOR_H
@@ -54,23 +41,23 @@ public:
     {
     }
   using ObjectImpVisitor::visit;
-  void visit( const LineImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const PointImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const TextImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const AngleImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const VectorImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const LocusImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const CircleImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const ConicImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const CubicImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const SegmentImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const RayImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const ArcImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const FilledPolygonImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const ClosedPolygonalImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const OpenPolygonalImp* imp ) Q_DECL_OVERRIDE;
-  void visit( const BezierImp* imp) Q_DECL_OVERRIDE;
-  void visit( const RationalBezierImp* imp) Q_DECL_OVERRIDE;
+  void visit( const LineImp* imp ) override;
+  void visit( const PointImp* imp ) override;
+  void visit( const TextImp* imp ) override;
+  void visit( const AngleImp* imp ) override;
+  void visit( const VectorImp* imp ) override;
+  void visit( const LocusImp* imp ) override;
+  void visit( const CircleImp* imp ) override;
+  void visit( const ConicImp* imp ) override;
+  void visit( const CubicImp* imp ) override;
+  void visit( const SegmentImp* imp ) override;
+  void visit( const RayImp* imp ) override;
+  void visit( const ArcImp* imp ) override;
+  void visit( const FilledPolygonImp* imp ) override;
+  void visit( const ClosedPolygonalImp* imp ) override;
+  void visit( const OpenPolygonalImp* imp ) override;
+  void visit( const BezierImp* imp) override;
+  void visit( const RationalBezierImp* imp) override;
 
   double unit;
 
