@@ -34,6 +34,7 @@
 #include <KCursor>
 #include <QDebug>
 #include <KMessageBox>
+#include <KLazyLocalizedString>
 
 #include <algorithm>
 #include <functional>
@@ -81,7 +82,7 @@ TextLabelModeBase::~TextLabelModeBase()
 TextLabelModeBase::TextLabelModeBase( KigPart& doc )
   : KigMode( doc ), d( new Private )
 {
-  d->locationparent = 0;
+  d->locationparent = nullptr;
   d->lpc = 0;
   d->mwawd = SelectingLocation;
   d->wiz = new TextLabelWizard( doc.widget(), this );
@@ -104,7 +105,7 @@ void TextLabelModeBase::leftClicked( QMouseEvent* e, KigWidget* )
 
 void TextLabelModeBase::leftReleased( QMouseEvent* e, KigWidget* v )
 {
-  leftReleased( e, v, 0 );
+  leftReleased( e, v, nullptr );
 }
 
 /*
@@ -155,11 +156,11 @@ void TextLabelModeBase::leftReleased( QMouseEvent* e, KigWidget* v,
     p.setObjectName( QStringLiteral("text_label_select_arg_popup") );
     QAction* act = p.addAction( i18n( "Name" ) );
     act->setData( QVariant::fromValue( 0 ) );
-    QByteArrayList l = o->imp()->properties();
+    QList<KLazyLocalizedString> l = o->imp()->properties();
     assert( l.size() == o->imp()->numberOfProperties() );
     for ( int i = 0; i < l.size(); ++i )
     {
-      QString s = i18n( l[i] );
+      QString s = l[i].toString();
       const char* iconfile = o->imp()->iconForProperty( i );
       if ( iconfile && *iconfile )
       {
@@ -233,7 +234,7 @@ void TextLabelModeBase::mouseMoved( QMouseEvent* e, KigWidget* w )
   {
     std::vector<ObjectHolder*> os = mdoc.document().whatAmIOn( w->fromScreen( e->pos() ), *w );
     bool attachable = false;
-    d->locationparent = 0;
+    d->locationparent = nullptr;
     for ( std::vector<ObjectHolder*>::iterator i = os.begin(); i != os.end(); ++i )
     {
       if( (*i)->imp()->attachPoint().valid() ||
@@ -264,7 +265,7 @@ void TextLabelModeBase::mouseMoved( QMouseEvent* e, KigWidget* w )
     else
     {
       w->setCursor( Qt::CrossCursor );
-      mdoc.emitStatusBarText( 0 );
+      mdoc.emitStatusBarText( nullptr );
       w->updateWidget();
     };
   }
@@ -309,7 +310,7 @@ bool TextLabelModeBase::canFinish()
     assert( d->args.size() == 0 );
 
   for ( argvect::iterator i = d->args.begin(); i != d->args.end(); ++i )
-    finish = finish && ( *i != 0 );
+    finish = finish && ( *i != nullptr );
 
   if ( ! finish )
   {
@@ -339,14 +340,14 @@ bool TextLabelModeBase::percentCountChanged( uint percentcount )
   }
   else if ( d->lpc < percentcount )
   {
-    d->args.resize( percentcount, 0 );
+    d->args.resize( percentcount, nullptr );
   };
 
   if ( percentcount != 0 )
   {
     bool finished = true;
     for ( argvect::iterator i = d->args.begin(); i != d->args.end(); ++i )
-      finished &= ( *i != 0 );
+      finished &= ( *i != nullptr );
     assert( percentcount == d->args.size() );
     finish = finished;
   };
@@ -470,7 +471,7 @@ void TextLabelConstructionMode::finish(
         i != props.end(); ++i )
     args.push_back( i->get() );
 
-  ObjectHolder* label = 0;
+  ObjectHolder* label = nullptr;
   if ( locationparent )
     label = ObjectFactory::instance()->attachedLabel( s, locationparent, coord, needframe, args, mdoc.document() );
   else
@@ -569,7 +570,7 @@ void TextLabelRedefineMode::finish(
    * is actually a child of this label
    */
   if ( locationparent && isChild( locationparent, mlabel ) )
-    locationparent = 0;
+    locationparent = nullptr;
   /*
    * take advantage of the method "getAttachPoint" that should
    * do all the work; it is also used when creating a new label
