@@ -55,7 +55,7 @@ public:
                               const KigDocument& doc ) const;
 
   int numberOfProperties() const override;
-  const QByteArrayList properties() const override;
+  const QList<KLazyLocalizedString> properties() const override;
   const QByteArrayList propertiesInternalNames() const override;
   ObjectImp* property( int which, const KigDocument& w ) const override;
   const char* iconForProperty( int which ) const override;
@@ -126,7 +126,7 @@ public:
                               const KigDocument& doc ) const;
 
   int numberOfProperties() const override;
-  const QByteArrayList properties() const override;
+  const QList<KLazyLocalizedString> properties() const override;
   const QByteArrayList propertiesInternalNames() const override;
   ObjectImp* property( int which, const KigDocument& w ) const override;
   const char* iconForProperty( int which ) const override;
