@@ -18,8 +18,8 @@ class CircleBCPType
 public:
   static const CircleBCPType* instance();
 
-  ObjectImp* calcx( const Coordinate& a, const Coordinate& b ) const Q_DECL_OVERRIDE;
-  const ObjectImpType* resultId() const Q_DECL_OVERRIDE;
+  ObjectImp* calcx( const Coordinate& a, const Coordinate& b ) const override;
+  const ObjectImpType* resultId() const override;
 };
 
 /**
@@ -33,8 +33,8 @@ class CircleBPRType
 public:
   static const CircleBPRType* instance();
 
-  ObjectImp* calc( const Args& args, const KigDocument& ) const Q_DECL_OVERRIDE;
-  const ObjectImpType* resultId() const Q_DECL_OVERRIDE;
+  ObjectImp* calc( const Args& args, const KigDocument& ) const override;
+  const ObjectImpType* resultId() const override;
 };
 
 /**
@@ -49,8 +49,8 @@ class CircleBTPType
 public:
   static const CircleBTPType* instance();
 
-  ObjectImp* calc( const Args& args, const KigDocument& ) const Q_DECL_OVERRIDE;
-  const ObjectImpType* resultId() const Q_DECL_OVERRIDE;
+  ObjectImp* calc( const Args& args, const KigDocument& ) const override;
+  const ObjectImpType* resultId() const override;
 };
 
 
